{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "dd-MM-y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-one" => "MMMM \N{U+098f}\N{U+09b0} W\N{U+09af}\N{U+09bc} \N{U+09b8}\N{U+09aa}\N{U+09cd}\N{U+09a4}\N{U+09be}\N{U+09b9}",
    "MMMMW-count-other" => "MMMM \N{U+098f}\N{U+09b0} W\N{U+09af}\N{U+09bc} \N{U+09b8}\N{U+09aa}\N{U+09cd}\N{U+09a4}\N{U+09be}\N{U+09b9}",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+098f}\N{U+09b0} w\N{U+09a4}\N{U+09ae} \N{U+09b8}\N{U+09aa}\N{U+09cd}\N{U+09a4}\N{U+09be}\N{U+09b9}",
    "yw-count-other" => "Y \N{U+098f}\N{U+09b0} w\N{U+09a4}\N{U+09ae} \N{U+09b8}\N{U+09aa}\N{U+09cd}\N{U+09a4}\N{U+09be}\N{U+09b9}",
  },
  code => "bn-BD",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+09b8}\N{U+09cb}\N{U+09ae}",
    "\N{U+09ae}\N{U+0999}\N{U+09cd}\N{U+0997}\N{U+09b2}",
    "\N{U+09ac}\N{U+09c1}\N{U+09a7}",
    "\N{U+09ac}\N{U+09c3}\N{U+09b9}\N{U+09b8}\N{U+09cd}\N{U+09aa}\N{U+09a4}\N{U+09bf}",
    "\N{U+09b6}\N{U+09c1}\N{U+0995}\N{U+09cd}\N{U+09b0}",
    "\N{U+09b6}\N{U+09a8}\N{U+09bf}",
    "\N{U+09b0}\N{U+09ac}\N{U+09bf}",
  ],
  day_format_narrow => [
    "\N{U+09b8}\N{U+09cb}",
    "\N{U+09ae}",
    "\N{U+09ac}\N{U+09c1}",
    "\N{U+09ac}\N{U+09c3}",
    "\N{U+09b6}\N{U+09c1}",
    "\N{U+09b6}",
    "\N{U+09b0}",
  ],
  day_format_wide => [
    "\N{U+09b8}\N{U+09cb}\N{U+09ae}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ae}\N{U+0999}\N{U+09cd}\N{U+0997}\N{U+09b2}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ac}\N{U+09c1}\N{U+09a7}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ac}\N{U+09c3}\N{U+09b9}\N{U+09b8}\N{U+09cd}\N{U+09aa}\N{U+09a4}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b6}\N{U+09c1}\N{U+0995}\N{U+09cd}\N{U+09b0}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b6}\N{U+09a8}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b0}\N{U+09ac}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+09b8}\N{U+09cb}\N{U+09ae}",
    "\N{U+09ae}\N{U+0999}\N{U+09cd}\N{U+0997}\N{U+09b2}",
    "\N{U+09ac}\N{U+09c1}\N{U+09a7}",
    "\N{U+09ac}\N{U+09c3}\N{U+09b9}\N{U+09b8}\N{U+09cd}\N{U+09aa}\N{U+09a4}\N{U+09bf}",
    "\N{U+09b6}\N{U+09c1}\N{U+0995}\N{U+09cd}\N{U+09b0}",
    "\N{U+09b6}\N{U+09a8}\N{U+09bf}",
    "\N{U+09b0}\N{U+09ac}\N{U+09bf}",
  ],
  day_stand_alone_narrow => [
    "\N{U+09b8}\N{U+09cb}",
    "\N{U+09ae}",
    "\N{U+09ac}\N{U+09c1}",
    "\N{U+09ac}\N{U+09c3}",
    "\N{U+09b6}\N{U+09c1}",
    "\N{U+09b6}",
    "\N{U+09b0}",
  ],
  day_stand_alone_wide => [
    "\N{U+09b8}\N{U+09cb}\N{U+09ae}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ae}\N{U+0999}\N{U+09cd}\N{U+0997}\N{U+09b2}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ac}\N{U+09c1}\N{U+09a7}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09ac}\N{U+09c3}\N{U+09b9}\N{U+09b8}\N{U+09cd}\N{U+09aa}\N{U+09a4}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b6}\N{U+09c1}\N{U+0995}\N{U+09cd}\N{U+09b0}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b6}\N{U+09a8}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
    "\N{U+09b0}\N{U+09ac}\N{U+09bf}\N{U+09ac}\N{U+09be}\N{U+09b0}",
  ],
  era_abbreviated => [
    "\N{U+0996}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b8}\N{U+09cd}\N{U+099f}\N{U+09aa}\N{U+09c2}\N{U+09b0}\N{U+09cd}\N{U+09ac}",
    "\N{U+0996}\N{U+09c3}\N{U+09b7}\N{U+09cd}\N{U+099f}\N{U+09be}\N{U+09ac}\N{U+09cd}\N{U+09a6}",
  ],
  era_narrow => [
    "\N{U+0996}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b8}\N{U+09cd}\N{U+099f}\N{U+09aa}\N{U+09c2}\N{U+09b0}\N{U+09cd}\N{U+09ac}",
    "\N{U+0996}\N{U+09c3}\N{U+09b7}\N{U+09cd}\N{U+099f}\N{U+09be}\N{U+09ac}\N{U+09cd}\N{U+09a6}",
  ],
  era_wide => [
    "\N{U+0996}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b8}\N{U+09cd}\N{U+099f}\N{U+09aa}\N{U+09c2}\N{U+09b0}\N{U+09cd}\N{U+09ac}",
    "\N{U+0996}\N{U+09cd}\N{U+09b0}\N{U+09c0}\N{U+09b7}\N{U+09cd}\N{U+099f}\N{U+09be}\N{U+09ac}\N{U+09cd}\N{U+09a6}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-d/%-m/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Bangla",
  month_format_abbreviated => [
    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}",
    "\N{U+09ab}\N{U+09c7}\N{U+09ac}",
    "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}\N{U+09b2}",
    "\N{U+0986}\N{U+0997}",
    "\N{U+09b8}\N{U+09c7}\N{U+09aa}",
    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}",
    "\N{U+09a8}\N{U+09ad}\N{U+09c7}",
    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}",
  ],
  month_format_narrow => [
    "\N{U+099c}\N{U+09be}",
    "\N{U+09ab}\N{U+09c7}",
    "\N{U+09ae}\N{U+09be}",
    "\N{U+098f}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}",
    "\N{U+0986}",
    "\N{U+09b8}\N{U+09c7}",
    "\N{U+0985}",
    "\N{U+09a8}",
    "\N{U+09a1}\N{U+09bf}",
  ],
  month_format_wide => [
    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
    "\N{U+09ab}\N{U+09c7}\N{U+09ac}\N{U+09cd}\N{U+09b0}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
    "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b2}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}\N{U+09b2}\N{U+09be}\N{U+0987}",
    "\N{U+0986}\N{U+0997}\N{U+09b8}\N{U+09cd}\N{U+099f}",
    "\N{U+09b8}\N{U+09c7}\N{U+09aa}\N{U+09cd}\N{U+099f}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a8}\N{U+09ad}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}",
    "\N{U+09ab}\N{U+09c7}\N{U+09ac}",
    "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b2}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}\N{U+09b2}\N{U+09be}\N{U+0987}",
    "\N{U+0986}\N{U+0997}\N{U+09b8}\N{U+09cd}\N{U+099f}",
    "\N{U+09b8}\N{U+09c7}\N{U+09aa}\N{U+09cd}\N{U+099f}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a8}\N{U+09ad}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
  ],
  month_stand_alone_narrow => [
    "\N{U+099c}\N{U+09be}",
    "\N{U+09ab}\N{U+09c7}",
    "\N{U+09ae}\N{U+09be}",
    "\N{U+098f}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}",
    "\N{U+0986}",
    "\N{U+09b8}\N{U+09c7}",
    "\N{U+0985}",
    "\N{U+09a8}",
    "\N{U+09a1}\N{U+09bf}",
  ],
  month_stand_alone_wide => [
    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
    "\N{U+09ab}\N{U+09c7}\N{U+09ac}\N{U+09cd}\N{U+09b0}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
    "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b2}",
    "\N{U+09ae}\N{U+09c7}",
    "\N{U+099c}\N{U+09c1}\N{U+09a8}",
    "\N{U+099c}\N{U+09c1}\N{U+09b2}\N{U+09be}\N{U+0987}",
    "\N{U+0986}\N{U+0997}\N{U+09b8}\N{U+09cd}\N{U+099f}",
    "\N{U+09b8}\N{U+09c7}\N{U+09aa}\N{U+09cd}\N{U+099f}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a8}\N{U+09ad}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
  ],
  name => "Bangla Bangladesh",
  native_language => "\N{U+09ac}\N{U+09be}\N{U+0982}\N{U+09b2}\N{U+09be}",
  native_name => "\N{U+09ac}\N{U+09be}\N{U+0982}\N{U+09b2}\N{U+09be} \N{U+09ac}\N{U+09be}\N{U+0982}\N{U+09b2}\N{U+09be}\N{U+09a6}\N{U+09c7}\N{U+09b6}",
  native_script => undef,
  native_territory => "\N{U+09ac}\N{U+09be}\N{U+0982}\N{U+09b2}\N{U+09be}\N{U+09a6}\N{U+09c7}\N{U+09b6}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a6}\N{U+09cd}\N{U+09ac}\N{U+09bf}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a4}\N{U+09c3}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+099a}\N{U+09a4}\N{U+09c1}\N{U+09b0}\N{U+09cd}\N{U+09a5} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
  ],
  quarter_format_narrow => [
    "\N{U+09e7}",
    "\N{U+09e8}",
    "\N{U+09e9}",
    "\N{U+09ea}",
  ],
  quarter_format_wide => [
    "\N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a6}\N{U+09cd}\N{U+09ac}\N{U+09bf}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a4}\N{U+09c3}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+099a}\N{U+09a4}\N{U+09c1}\N{U+09b0}\N{U+09cd}\N{U+09a5} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    "\N{U+09e7}",
    "\N{U+09e8}",
    "\N{U+09e9}",
    "\N{U+09ea}",
  ],
  quarter_stand_alone_wide => [
    "\N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a6}\N{U+09cd}\N{U+09ac}\N{U+09bf}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+09a4}\N{U+09c3}\N{U+09a4}\N{U+09c0}\N{U+09af}\N{U+09bc} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
    "\N{U+099a}\N{U+09a4}\N{U+09c1}\N{U+09b0}\N{U+09cd}\N{U+09a5} \N{U+09a4}\N{U+09cd}\N{U+09b0}\N{U+09c8}\N{U+09ae}\N{U+09be}\N{U+09b8}\N{U+09bf}\N{U+0995}",
  ],
  script => undef,
  territory => "Bangladesh",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 42,
}
